#
# spec file for package libosinfo
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define with_lang 1

Name:           libosinfo
VCS: https://src.suse.de/SLFO-pool/libosinfo#ed8e3275023d2a1a56109f4a6d558876ba79d23def2e12cf0c1c62e2a6aa2387
Version:        1.12.0
Release:        160000.1.16
Summary:        Operating system and hypervisor information management library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
URL:            https://releases.pagure.org/libosinfo
Source0:        %{url}/%{name}-%{version}.tar.xz

BuildRequires:  gtk-doc
BuildRequires:  hwdata
BuildRequires:  libcurl-devel
BuildRequires:  meson
BuildRequires:  vala
BuildRequires:  pkgconfig(check)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
%if 0%{?suse_version} <= 1500 && 0%{?sle_version} < 150600
BuildRequires:  pkgconfig(libsoup-2.4)
%else
BuildRequires:  pkgconfig(libsoup-3.0)
%endif
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libxslt) >= 1.0.0
Requires:       osinfo-db
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package -n libosinfo-1_0-0
Summary:        Operating system and hypervisor information management library
Group:          System/Libraries
Requires:       %{name} >= %{version}
# for usb.ids and pci.ids
Requires:       hwdata

%description -n libosinfo-1_0-0
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package -n typelib-1_0-Libosinfo-1_0
Summary:        Typelib files for libosinfo
Group:          System/Libraries

%description -n typelib-1_0-Libosinfo-1_0
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

%package devel
Summary:        Header files for libosinfo, an OS/hypervisor information library
Group:          Development/Languages/C and C++
Requires:       libosinfo-1_0-0 = %{version}
Requires:       typelib-1_0-Libosinfo-1_0 = %{version}

%description devel
libosinfo is a library that allows virtualization provisioning tools to
determine the optimal device settings for a hypervisor/operating system
combination.

This package provides includes to compile with the libosinfo library,
as well as Vala bindings for the libosinfo library.

%if %{with_lang}
%lang_package
%endif

%prep
%autosetup -p1

%build
%meson \
    -Denable-gtk-doc=true \
    -Denable-tests=true \
    -Denable-introspection=enabled \
    -Denable-vala=enabled
%meson_build

%install
%meson_install
find %{buildroot} -type f -name "*.la" -delete -print
%if %{with_lang}
%find_lang %{name} %{?no_lang_C}
%endif

%ldconfig_scriptlets -n libosinfo-1_0-0

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/osinfo-detect
%{_bindir}/osinfo-install-script
%{_bindir}/osinfo-query
%{_mandir}/man1/osinfo-detect.1%{?ext_man}
%{_mandir}/man1/osinfo-install-script.1%{?ext_man}
%{_mandir}/man1/osinfo-query.1%{?ext_man}

%files -n libosinfo-1_0-0
%{_libdir}/libosinfo-1.0.so.*

%files -n typelib-1_0-Libosinfo-1_0
%{_libdir}/girepository-1.0/Libosinfo-1.0.typelib

%files devel
%{_datadir}/gtk-doc/
%{_includedir}/%{name}-1.0
%{_libdir}/pkgconfig/%{name}-1.0.pc
%{_libdir}/libosinfo-1.0.so
%{_datadir}/gir-1.0/Libosinfo-1.0.gir
%dir %{_datadir}/vala
%dir %{_datadir}/vala/vapi
%{_datadir}/vala/vapi/libosinfo-1.0.deps
%{_datadir}/vala/vapi/libosinfo-1.0.vapi

%if %{with_lang}
%files lang -f %{name}.lang
%endif

%changelog
* Mon Dec  2 2024 carnold@suse.com
- Update to version 1.12.0 (jsc#PED-8910)
  * Some memory leak fixes
  * Adapt to change in libxml2
  * Several CI improvements
  * Several translations improvements
- Drop 0001-osinfo-Make-xmlError-struct-constant-in-propagate_li.patch
* Sun May 26 2024 christophe@krop.fr
- Add upstream change:
  * 0001-osinfo-Make-xmlError-struct-constant-in-propagate_li.patch
* Mon Mar  4 2024 carnold@suse.com
- bsc#1220228 - virt-manager crashes when its viewer is opened on a
  running guest that uses spice graphics
  virt-manager uses both libosinfo and spice-gtk. spice-gtk is now
  built to use libsoup 3.0 but libosinfo was still using
  libsoup 2.4. Prefer libsoup 3.0 over libsoup 2.4 for Tumbleweed
  and newer SLE versions.
* Tue Jan 16 2024 dimstar@opensuse.org
- Own /usr/share/gtk-doc: glib no longer uses gtk-doc and as a
  consequence cannot be held responsible to deliver that basic
  directory structure.
* Mon Nov 13 2023 carnold@suse.com
- Update to version 1.11.0 (jsc#PED-6305)
  Changes in this release include:
  * Several minor memory leak fixes
  * Several CI improvements
  * Several translations improvements
- Drop 3a0fef72.patch as it is now part of the tarball
* Tue Oct  4 2022 carnold@suse.com
- jsc#PED-2113 [Virt Tools] Refresh Virtualization Tools for Xen
  and KVM Management
* Wed Aug 31 2022 bjorn.lie@gmail.com
- Add 3a0fef72.patch: build: Add option to select libsoup ABI.
  Following this, add conditional pkgconfig(libsoup-3.0)
  BuildRequires.
- Modernize spec, use ldconfig_scriptlets macro for post(un)
  handling, package COPYING with license macro.
* Wed Mar 30 2022 carnold@suse.com
- bsc#1197769 - FTBFS: libosinfo won't compile on SP4
  libosinfo.spec
* Tue Mar  1 2022 carnold@suse.com
- Update to version 1.10.0
  Changes in this release include:
  * Add API for resolving multiple tree matches
  * Add API for resolving multiple media matches
  * Add API to match between two OsinfoTree
  * Add API to match between two OsinfoMedia
  * Add API to get a complete list of firmwares
  * Add missing documentation of osinfo_os_add_firmware()
  * Add release status to osinfo-query
  * Add --all flag to all tools to report all matches
  * Fix hiding database entries
  * Adapt to libsoup3 which is now preferred over libsoup2
  * Several CI improvements
  * Several translations improvements
* Tue Mar  2 2021 carnold@suse.com
- Update to version 1.9.0
  Changes in this release include:
  * Improve on the osinfo-tools' and osinfo-detect's help
  * Several CI improvements
  * Several translations improvements
  * Improve on debuggability of the loader code
  * Fix build when using clang
* Tue Aug 18 2020 dimstar@opensuse.org
- Explicitly call %%meson_build in the %%build section: It was never
  needed (but should have been there) before as the %%meson_install
  macro would perform a project rebuild. However, most recent
  versions of meson have changed the %%meson_install macro to use
  `--no-rebuild`, exposing then this issue on our spec file.
* Mon Jun  1 2020 carnold@suse.com
- Update to version 1.8.0
  Changes in this release include:
  * Several CI improvements
  * Several release scripts improvements
  * Several translations improvements
  * Several syntax-check improvements
  * Code cleanup in order to modernize the GObject usage
  * Add API to get whether a firmware is supported or not
  * Add API to get "cloud-image-username"
* Tue Feb  4 2020 bjorn.lie@gmail.com
- No longer recommend -lang: supplements are in use.
* Wed Jan  8 2020 carnold@suse.com
- Drop ids.tar.bz2 in favor of using hwdata. (boo#1159838)
* Fri Dec 27 2019 dimstar@opensuse.org
- BuildRequire and Require hwdata: usb.ids and pci.ids are shipped
  and maintained by this package. Prior to version 1.7.x, libosinfo
  shipped own, outdated copies (boo#1159838).
* Wed Dec  4 2019 carnold@suse.com
- Update to version 1.7.1
  Changes in this release include:
  * Fix usage of versioned symbols
  * MinGW spec file fixes and improvements
  * Fix pci.ids and usb.ids installation
* Mon Dec  2 2019 carnold@suse.com
- Update to version 1.7.0
  Changes in this release include:
  * Add API to expose a device driver "priority"
  * Improve media detection when using "volume-size" to distinguish medias
  * General improvements on OsinfoList APIs to avoid unsafe access
  * Minor POD fixes
  * Switch to meson build system
  * Add API to expose "firmware" support on OsinfoOS
  * Drop "env" type support from osinfo-detect
  * Print the architecture of the detected tree / media on osinfo-detect
  * Add API to create an OsinfoTree from a treeinfo file
* Fri Jul 26 2019 carnold@suse.com
- Update to version 1.6.0
  Changes in this release include:
  * Add API to get the kernel URL argument for an OsinfoOs
  * Improve detection of PPC ISOs
  * Add API to create an OsinfoMedia from location using OsinfoMediaDetectFlags
  * Add API to get whether a media is bootable or not
  * Add OsinfoTree treeinfo properties
  * Add API to identify an OsinfoTree
  * Deprecate API to guess an OsinfoOs from OsinfoTree
  * Add --config-file to osinfo-install-script tool
  * Deprecate --config usage for user & admin passwords on osinfo-install-script tool
  * Add API to generate an install-script and its command-line for OsinfoTree
  * Use libsoup for "http://" & "https://" requests for creating both OsinfoMedia & OsinfoTree
  * Drop GVFS dependency
  * Add OsinfoOs property to OsinfoTree
- Drop
  CVE-2019-13313-add-new-option-so-users-can-set-config-from-file.patch
  CVE-2019-13313-pass-username-password-via-config-file.patch
* Mon Jul  8 2019 carnold@suse.com
- bsc#1140749 - VUL-1: CVE-2019-13313: libosinfo: osinfo-install-
  script option leaks password via command line argument
  CVE-2019-13313-add-new-option-so-users-can-set-config-from-file.patch
  CVE-2019-13313-pass-username-password-via-config-file.patch
* Thu May  9 2019 carnold@suse.com
- Update to version 1.5.0
  Changes in this release include:
  * Add API to get an OS from OsinfoTrees & OsinfoImages
  * Add API to set an OS to OsinfoTrees & OsinfoImages
  * Add API to get the OS variants from OsinfoTrees & OsinfoImages
  * Add API to set the installation URL to a OsinfoInstallConfig
  * Add API to get all short-ids from an OsinfoProduct
  * Improve OsinfoLoader in order to fully support multiple short-ids values on
    an OsinfoProduct
  * Improve osinfo-detect tool's help wording
  * Improve osinfo-detect tool, making it aware of OsinfoTree's OS variants
  * Fix the loading of the architecture value of OsinfoImages
  * Fix usage of application id on media detection
  * Accept "all" as a valid fallback architecture for OsinfoTrees & OsinfoMedias
  * Improve treeinfo check by checking for both ".treeinfo" and "treeinfo" files
  * Explicitly set GVFS as a requirement in the project spec file
  * Move osinfo-db related tests to osinfo-db project
- Drop
  0001-media-Fix-usage-of-application-id.patch
  0002-loader-Properly-load-the-arch-value-for-images.patch
* Wed Apr 10 2019 carnold@suse.com
- Upstream bug fixes from Fabiano Fidêncio <fabiano@fidencio.org>
  0001-media-Fix-usage-of-application-id.patch
  0002-loader-Properly-load-the-arch-value-for-images.patch
* Fri Mar  1 2019 carnold@suse.com
- Update to version 1.4.0
  Changes in this release include:
  * Add isodata test files for more distros
  * Refreshed translations from Zanata
  * Drop deprecated gnome-common and intltool
  * Fix test cases checking for medias, trees and images URIs due to
    libcurl issues when reusing the curl handler
  * Fix media identification when its identifiers have the maximum
    allowed size
  * Fix filling up the media properties when identifying it
  * Improvements in the tests in order to reduce code duplication
  * Add one test case per OS for medias, trees and images URIs tests
  * Add OSINFO_RELEASE_STATUS_ROLLING release status
  * Add API to add an installer script to a media
  * Add API to get all the installer scripts from a media
* Mon Feb  4 2019 jengelh@inai.de
- Use noun phrase in summaries.
* Mon Feb  4 2019 carnold@suse.com
- Update to version 1.3.0
  Changes in this release include:
  * Add isodata test files for many more distros
  * Refreshed translations from Zanata
  * Refuse to load data files which do not follow the
    documented directory layout and file naming conventions
    introduced in version 0.3.0
  * Avoid warnings when setting GError objects with new glib
  * Remove outdated FSF address from source file headers
  * Make several test suites collect & report all errors
    before exiting with failure for easy diagnosis
  * Avoid misc memory leaks
  * Add support for reporting maximum resource settings
  * Add support for reporting network installer resource settings
  * Fix data returned for osinfo_devicelinklist_get_devices
  * Support removal of devices during inheritance processing
  * Support inheritance of resources settings
  * Add OsinfoImage class & related APIs for reporting
    pre-installed disk images
  * Add API to determine if treeinfo metadata is provided
  * Add API to determine if media supports installer scripts
  * Add API to determine preferred install script injection
    methods
  * Add support for detecting if PPC ISO images are bootable
* Wed Jun 20 2018 carnold@suse.com
- Update to version 1.2.0
  Changes in this release include:
  * Test suite requires osinfo-db >= 20180612
  * Replace use of libsoup with libcurl in test suite
  * Replace use of check library with GLib tester in test suite
  * Increase timeout for media URIs test
  * Drop const parameter annotations which break Rust generator
  * Improve error message with ISO test fails
  * Turn off -Wfunction-cast-type warning from gcc 8
  * Remove calls to g_log_set_always_fatal in tests
  * Load database files in alphabetical order for predictable sorting
  * Fix leak of list when loading files
  * Fix build of tools with clang 6
  * Add missing “global” annotation on some symbol versions
* Tue Aug 15 2017 carnold@suse.com
- Update to version 1.1.0
  Changes in this release include:
  * Force UTF-8 locale for new glib-mkenums
  * Avoid python warnings in example program
  * Misc test suite updates
  * Fix typo in error messages
  * Remove ISO header string padding
  * Disable bogus gcc warning about unsafe loop optimizations
  * Remove reference to fedorahosted.org
  * Don't hardcode /usr/bin/perl, use /usr/bin/env
  * Support eject-after-install parameter in OsinfoMedia
  * Fix misc warnings in docs
  * Fix error propagation when loading DB
  * Add usb.ids / pci.ids locations for FreeBSD
  * Don't include private headers in gir/vapi generation
* Mon Dec 12 2016 carnold@suse.com
- Update to version 1.0.0 (bsc#1013983)
  Changes in this release include:
  * Update loader to follow new layout for external database
  * Move all database files into separate osinfo-db package
  * Move osinfo-db-validate into osinfo-db-tools package
- Patches moved to osinfo-db package (dropped from libosinfo)
  0ae4f0db-add-missing-sle12-distros.patch
  1a7ce161-add-sle-resource-information.patch
  3c621fd8-add-opensuse-date-information.patch
  470b7652-add-opensuse-device-information.patch
  50091807-add-sle-device-information.patch
  67c74e5f-add-opensuse-leap-42.2-support.patch
  99ae3d72-add-sle12sp2-support.patch
  99f7e666-fix-opensuse-derives-from-information.patch
  9a35cea7-fix-sle-derives-from-information.patch
  9dec2be8-add-sle-date-information.patch
  e77abec7-add-opensuse-resource-information.patch
  f0d44d88-add-missing-sle10-distros.patch
* Tue Dec  6 2016 carnold@suse.com
- bsc#1013983 - incomplete capabilities list of SLE and openSUSE
  distributions in libosinfo
  0ae4f0db-add-missing-sle12-distros.patch
  1a7ce161-add-sle-resource-information.patch
  3c621fd8-add-opensuse-date-information.patch
  470b7652-add-opensuse-device-information.patch
  50091807-add-sle-device-information.patch
  67c74e5f-add-opensuse-leap-42.2-support.patch
  99ae3d72-add-sle12sp2-support.patch
  99f7e666-fix-opensuse-derives-from-information.patch
  9a35cea7-fix-sle-derives-from-information.patch
  9dec2be8-add-sle-date-information.patch
  e77abec7-add-opensuse-resource-information.patch
  f0d44d88-add-missing-sle10-distros.patch
- Dropped or renamed
  0ae4f0db-add-missing-sles-distros.patch
  add-missing-sle10-distros.patch
  add-opensuse-leap-42.2-support.patch
  add-sle12sp2-support-for-arch.patch
  add-sle12sp2-support.patch
  Fix_derives-from_and_add_tablet_item.patch
* Thu Dec  1 2016 carnold@suse.com
- bsc#1012005 - [openqa virtualization] using the wrong bootloader
  tool to boot the sles-12-sp3 pv kernel on xen platform
  add-sle12sp3-support.patch
  add-opensuse-leap-42.3-support.patch
* Thu Oct  6 2016 carnold@suse.com
- bsc#1003456 - virt-install fails to detect openSUSE Leap 42.2 ISO
  add-opensuse-leap-42.2-support.patch
* Tue Sep 27 2016 carnold@suse.com
- bsc#1000188 - virt-install on aarch64 does not detect
  installation iso
  add-sle12sp2-support-for-arch.patch
* Sat Jul  2 2016 zaitor@opensuse.org
- Update to version 0.3.1:
  + Require glib2 >= 2.36.
  + Replace GSimpleAsyncResult usage with GTask.
  + Fix VPATH based builds.
  + Don't include autogenerated enum files in dist.
  + Fix build with older GCC versions.
  + Add/improve/fix data for: Debian, SLES/SLED, OpenSUSE, FreeBSD,
    Windows, RHEL, Ubuntu.
  + Update README content.
  + Fix string comparison for bootable media detection.
  + Fix linker flags for OS-X & solaris.
  + Fix darwin detection code.
  + Fix multiple memory leaks.
- Drop 0ae4f0db-add-missing-sles-distros.patch and
  92c55cab-add-missing-opensuse-distros.patch: Fixed upstream.
* Mon Jun 27 2016 carnold@suse.com
- bsc#986731 - libosinfo: Add support for openSUSE Leap 42.2
  add-opensuse-leap-42.2-support.patch
* Tue May 10 2016 carnold@suse.com
- bsc#979369 - libosinfo: Missing sle10 distro versions
  add-missing-sle10-distros.patch
* Wed Mar 30 2016 carnold@suse.com
- bsc#964407 - Virt-manager: Installer wrongly detects SLE-12-GA
  media as SLE-12-SP1
* Thu Mar 24 2016 carnold@suse.com
- Replace patches with upstream version
  0ae4f0db-add-missing-sles-distros.patch
  92c55cab-add-missing-opensuse-distros.patch
- Dropped
  add-missing-sles-distros.patch
  add-missing-opensuse-distros.patch
* Wed Mar 23 2016 carnold@suse.com
- Replace patches with newer versions
  add-missing-opensuse-distros.patch
  add-missing-sles-distros.patch
- Dropped patches:
  add-opensuse-leap-42.1-support.patch
  add-tumbleweed-support.patch
  add-sle12sp1-support.patch
* Wed Mar 16 2016 carnold@suse.com
- Fix version string for sled12sp2
  add-sle12sp2-support.patch
* Tue Mar 15 2016 carnold@suse.com
- bsc#971077 - virt-manager error: 'maximum recursion depth
  exceeded while calling a Python object' when installing TW as a
  KVM guest
  add-tumbleweed-support.patch
* Tue Feb  2 2016 carnold@suse.com
- Add support for detecting Tumbleweed
  add-tumbleweed-support.patch
* Tue Feb  2 2016 dimstar@opensuse.org
- Switch Tarball back to .gz which is provided by upstream.
* Mon Feb  1 2016 carnold@suse.com
- Add initial support for sles12sp2. This patch is preliminary and
  will be updated when sle12sp2 is actually released.
  add-sle12sp2-support.patch
* Thu Jan 21 2016 carnold@suse.com
- Update to version 0.3.0
  - Ditch custom udev rule since udev/blkid already expose ISO9660 properties.
  - New layout for database to facilitate local admin customization. Refer to
    docs/database-layout.txt for full details.
  - Many build-related fixes.
  - Plug many memory leaks.
  - Drop redundant information on PCI devices.
  - Fix the URI format for install scripts.
  - Memory corruption fixes.
  - Massive refactoring/cleanup of database.
  - Fixes to tests.
  - osinfo_loader_process_*() now expect a directory argument. Regular files are
    still supported but this support is deprecated.
  - Ensure Linux install scripts install qemu-guest-agent. This allows
    applications to do things like resyncing the clock of guest with that of host.
  - Add/improve/fix data on:
  - Alt Linux
  - CentOS
  - Debian
  - Fedora
  - FreeBSD
  - GNOME
  - KVM
  - Microsoft Windows 7, 8, 10 and Server 2012
  - Novell Netware
  - OpenBSD
  - openSUSE
  - PCI and PS/2 devices
  - Qemu
  - Red Hat Enterprise Linux
  - Red Hat Linux
  - Solaris
  - Ubuntu
  - Xen
  - Many internal cleanups.
- Drop
  1d08a23c-add-opensuse-13.2-support.patch
  7b31e3ac-add-qemu-2.3-support.patch
  6c3ddecb-add-rhel7.1-support.patch
  a563ad22-fix-fedora-unknown-regexp.patch
- Avoid using wget to download ids file
  ids.tar.bz2
* Wed Nov 25 2015 mlatimer@suse.com
- bsc#956756 - Correct typo in sles12 sp1 definition, which
  which prevents sles12 from being displayed in OS list
* Wed Oct 21 2015 lma@suse.com
- bsc#946157 - The mouse cursor doesn't work during Guest OS
    installation in KVM Mode
  Fix_derives-from_and_add_tablet_item.patch
- Use correct name for openSUSE Leap 42.1
* Fri Sep  4 2015 carnold@suse.com
- bsc#944605 - Libosinfo is missing an entry for openSUSE Leap 42.1
  add-opensuse-leap-42.1-support.patch
* Mon Jul 20 2015 carnold@suse.com
- bsc#938843 - Libosinfo has no support for sles/sled 12 sp1
  add-sle12sp1-support.patch
- Add additional support and fixes
  6c3ddecb-add-rhel7.1-support.patch
  7b31e3ac-add-qemu-2.3-support.patch
  a563ad22-fix-fedora-unknown-regexp.patch
* Fri Jun  5 2015 carnold@suse.com
- Add support for openSUSE 13.2
  1d08a23c-add-opensuse-13.2-support.patch
* Mon Jun  1 2015 carnold@suse.com
- fate#318394: Update virt-manager to the most current released
  version (requires libosinfo)
* Thu May 28 2015 zaitor@opensuse.org
- Update to version 0.2.12:
  + Add API to get/set ISO9660 volume size of media.
  + Make use of volume size of ISO files for detection. This
    enables us to differentiate between DVD and netiso of Fedora,
    for example.
  + Allow install trees to be associated with specific variants of
    the OS.
  + Use direct HTTPS URLs to drivers.
  + Install scripts:
  - Add API to generate script against a particular media.
  - Fix Fedora script to work with netiso.
  - Bigger /boot partition for Fedora and RHEL.
  - Don't specify network interface for Fedora and RHEL.
  + Add/improve/fix data on:
  - Debian 8.0.
  - Fedora (all versions).
  - GNOME 3.14.
  - Microsoft Windows Vista, 7 and 8.1.
  - OpenBSD 5.6.
  - openSUSE.
  - RHEL 5.9-11, 6.6 and Atomic 7.0.
  - SUSE.
  - Ubuntu 14.04 and 15.04.
  + Fix some leaks.
  + Fix and add some API documentation.
  + Many build fixes.
* Wed Aug 20 2014 dimstar@opensuse.org
- Update to version 0.2.11:
  + Document hostname limitations.
  + Export OSINFO_*_VERSION macros.
  + Add desktop scripts for Debian.
  + Add API to query install scripts if they require an internet
    connection.
  + Some fixes to Debian JEOS script.
  + Add/improve/fix data on:
  - CentOS
  - Debian
  - FreeBSD
  - Microsoft Windows 7
  - Microsoft Windows 8
  - Microsoft Windows Server 2012
  - Microsoft Vista
  - OpenBSD
  - OpenSUSE
  - Red Hat Enterprise Linux 7
  + More ISO detection testcases.
  + Many performance improvements.
  + Fixes to documentation.
  + Fixes to build.
* Wed Mar 26 2014 mgorse@suse.com
- Update to version 0.2.10:
  + Add API and option to osinfo-install-script utility that
    allows you to query the available methods to inject the
    installer script to the installation process.
  + Add JEOS installer scripts for Debian and Ubuntu.
  + Disable installer script for Windows 8.1 as its known not to work.
  + Allow XML special chars in installer script configuration values.
  + Fix a few build issues.
  + Add/improve/fix data on:
  - Debian
  - Fedora
  - FreeBSD
  - Mandrake
  - Mandriva
  - Microsoft Windows 7
  - openSUSE
  - Solaris
  - Ubuntu
  - Qemu
* Mon Dec 16 2013 dimstar@opensuse.org
- Update to version 0.2.9:
  + Add/improve/fix data on:
  - Debian
  - Fedora 20
  - GNOME continuous 3.12
  - Mageia
  - Microsoft Windows 7
  - Microsoft Windows 8.1
  - RHEL 5.8
  - RHEL 6.5
  - RHEL 7.0
  + Support '<foo/>' syntax for booleans in database, in addition
    to existing '<foo>true</foo>'.
  + New API/XML to determine/specify:
  - If an OS is an actual release, a pre-release or a development
    snapshot.
  - Variants of an OS. For example, professional, enterprise and
    ultimate editions of Windows OSs and workstation and server
    variants of RHEL etc.
  + Various fixes to build system.
  + More testcases.
  + Some other minor fixes/changes.
* Mon Sep 16 2013 zaitor@opensuse.org
- Update to version 0.2.8:
  + Add/improve/fix data on: ALTLinux, Fedora 19, Fedora 20,
    FreeBSD, GNOME 3.8, GNOME 3.10, Microsoft Windows 7, QEMU and
    Ubuntu.
  + Add testcases for media detection: Microsoft Windows Server
    2008 R2.
  + Fix export of public API.
  + Hide private API.
  + Fix a parallel build issue.
  + Fix build against latest intltool.
  + Drop usage of deprecated API.
* Tue May 14 2013 dimstar@opensuse.org
- Update to version 0.2.7:
  + Add/improve/fix data on: CentOS 6.*, Fedora 19, GNOME 3.8,
    openSUSE 12.3, RHEL 6.4 and Ubuntu 13.04.
  + Add testcases for media detection.
  + Installer script fixes/improvements:
  - Setup user avatar for Windows 7.
  - Fix against old RHEL and Fedora.
  - Specify installation method for Fedora.
  + New API:
  - osinfo_platform_get_all_devices().
  - osinfo_install_script_generate_command_line().
  + Build fixes.
  + Some portability improments/fixes.
  + Fixes `make syntax-check`.
  + More docs and fixes to existing docs.
* Mon Mar 18 2013 dimstar@opensuse.org
- Update to version 0.2.6:
  + New API to:
  - query signed status of device drivers.
  - query device driver signing requirement of installer scripts.
  - enable/disable installer script driver signing checks.
  + Use system-installed pci.ids/usb.ids files, if available.
  + Don't ignore vendor/device names from pci.ids/usb.ids files.
  + Corrections to RPM spec.
* Tue Mar 12 2013 dimstar@opensuse.org
- Update to version 0.2.5:
  + Make use of post-installation drivers in Windows 7 install
    scripts.
  + Windows 7 install script now requires product key.
  + Actually add install scripts for Windows 8. This was supposed
    to be merged in release 0.2.3.
  + Formalize architecture names in DB to align with libvirt.
  + Fixes to mingw RPM spec from Fedora.
  + Add a Windows 7 volume ID to DB.
- Changes from version 0.2.4:
  + Fix crash in osinfo-detect against non-bootable media.
  + osinfo-install-script now displays names of generated files.
  + Add an all-in-one virtio and QXL device driver setup binary to
    Windows XP and 7.
  + Make use of post-installation drivers in Windows XP installer
    scripts.
  + Log post-install commands of Windows XP to target disk.
  + Add/improve/fix data on:
  - QEMU/QEMU-KVM hypervisor
  - GNOME
  - openSUSE
  + RPM spec file changes (shipped template).
  + Adapt to glib 2.36.
  + Fix some build warnings.
  + Some other fixes and improvements.
* Tue Jan 15 2013 dimstar@opensuse.org
- Update to version 0.2.3:
  + Add datamaps for translating OS-neutral values to OS-specific
    ones, e.g some installer configuration parameters like
    keyboard, language and timezone etc.
  + New API to detect media that makes it possible to also query
    languages supported by the media.
  + Add install scripts for:
  - RHEL 6.x.
  - Microsoft Windows 8
  + Fix install script for Fedora 18.
  + Drop support for encoding in l10n install script configuration
    parameters.
  + Fix test build issues.
  + Fixes and improvements to documentation.
  + Fix potential issues spotted by Coverity.
  + Fix build for translations.
  + osinfo-install-script tool now has options to list available
    configuration parameters and profiles.
  + Add/improve data on:
  - RHEL
  - Debian
  - openSUSE
  - Microsoft Windows 7
  - Ubuntu
  - MacOS X
  + Updated translations.
- Enable translations: change with_lang defines to 1 as there are
  now translations available.
* Tue Dec 11 2012 vuntz@opensuse.org
- Update to version 0.2.2:
  + Loads of improvements and fixes to installer APIs and scripts.
  + Add API for information on downloadable device drivers.
  + Add/improve data on: RHEL, Windows 7, Windows 8, Windows XP.
  + Enable translations for many (potential) user-visible strings.
  + Correct default value for OsinfoMedia::installer-reboots.
  + Register enum types with gobject type system.
  + Add enum param getter/setter helpers.
  + OsinfoList is now instantiable and all its subclasses has been
    deprecated.
  + Various other fixes and improvements.
- Add intltool BuildRequires: needed for changes in the build
  system for translations.
- Add translation-related packaging machinery (lang subpackage, and
  Recommends for it in the main subpackage), but keep it disabled
  with a %%{with_lang} macro for now as there is no translation yet.
* Sat Oct 13 2012 dimstar@opensuse.org
- Update to version 0.2.1:
  + Fix and simplify udev rule.
  + Fedora:
  - Fix minimum RAM requirements for F16 and F17.
  + Add data on:
  - Fedora 18
  - GNOME 3.6
  - Ubuntu 12.10
  + Fixes to doc build.
  + Install script:
  - Add get_config_param method.
  - Differenciate between expected/output script names.
  - Add more utility functions.
  + Add 'installer-reboots' parameter to medias.
  + osinfo-detect does not die of DB loading errors anymore.
  + More type-specific entity value getters/setters.
  + Fixe and update RNG file.
  + Add 'subsystem' property/attribute to devices.
* Mon Sep  3 2012 dimstar@opensuse.org
- Update to version 0.2.0:
  + Fix build against mingw64 toolchain.
  + API for getting product logo URLs.
  + Fix architecture for a Windows 2008 media.
  + Remove bogus minimum storage information for Fedora.
  + Add varirables for system and local database paths in
    pkg-config.
- Add pkgconfig(libxslt) BuildRequires: new dependency.
* Mon Jun 18 2012 dimstar@opensuse.org
- Update to version 0.1.2:
  + Fix udev rules for CDROM media.
  + Fix build against newer glibc-headers when building with -O0.
  + More complete/up2date data for:
  - Fedora 17
  - Ubuntu
  - Windows
  + Fix data for:
  - Ubuntu
  + Correct order of elements returned by list union functions.
* Fri Apr 13 2012 dimstar@opensuse.org
- Update to version 0.1.1:
  + Fixes the OS media detection
  + Add support fro more OSs: NetBSD and Mandrake
  + More complete and fixed data
  + Add support for install tree metadata
  + Add support for filtering products cased on release/EOL dates.
  + Add support for product codenames.
  + Add support for 'distro'.
  + Also extract application ID from ISO9660 media.
  + Add test cases for validating ISO9660 data.
  + Disable obsolete media URLs.
  + Standardize OS family names as all lowercase.
  + Standardize format for OS id, short-id, distro, version.
  + Add RNG schema for database files.
  + Add a 'osinfo-db-validate' command for verifying database files
  + Add a 'osinfo-query' command for searching/listing information
    from database.
  + Add a man page for the osinfo-detect command.
  + Add support for loading extra local database files. By default,
    libosinfo will expect them to be in /etc/libosinfo/db and
    $HOME/.local/config/libosinfo/db  but new API is provided to
    change this behavior.
  + Fix generation of docs in a VPATH builder.
  + Fix loading of vendor and product names of USB and PCI devices.
  + Remove obsolete scripts for PCI/USB id conversion.
  + Remove redundant generic linux entries from database.
  + Fixes for 'make dist'.
  + Actually handle '--enable-vala' configure option and don't
    mandate vapigen if this option is not specified.
  + Add missing export of osinfo_entity_set_param.
  + Various other fixes and improvements.
- Add pkgconfig(libsoup-2.4) and pkgconfig(libsoup-gnome-2.4)
  BuildRequires: new upstream dependencies.
* Thu Feb  9 2012 dimstar@opensuse.org
- Update to version 0.1.0:
  + Add Utility function to retrieve OS devices by property.
  + Improved OS media detection.
  + Add missing 'const' OsinfoList function params.
  + Use ENV{} in udev rule.
* Thu Feb  2 2012 dimstar@opensuse.org
- Require libosinfo from the shared library package: the library
  does require the os identifier data.
* Tue Jan 31 2012 cfarrell@suse.com
- license update: LGPL-2.1+ and GPL-2.0+
  tools/osinfo-detect.c is GPL-2.0+ licensed
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 0.0.5:
  + Add QXL to supported devices of windows and Fedora.
  + Distribute and install forgotten device XML files.
  + Add all metadata from default path, not just OS.
  + List supported audio devices for Windows and Fedora.
  + Specify 'derives-from' relationship for Fedora OSs.
  + Add API to retreive all supported devices for an OS.
  + Fix some potential issues related to memory allocation/
    alignment.
- Changes from version 0.0.4:
  + Fix silly mistakes in udev rules file.
- Changes from version 0.0.3:
  + Add lots of more data on various different OSs out there. Now
    we also support some Apple OSs.
  + On successful OS detection, inform the application which known
    media of the OS the given media matched against. osinfo-detect
    tool and udev rule updated to make use of this.
  + Support applications' right to not be interested in error
    details.
  + Minor fixes/improvements to OS detection logic.
  + API to indicate media is live and/or installer.
  + Don't match non-live Fedora ISOs against live ones.
  + Fixes to Python demo to make it work.
  + Fix some potential crashes.
  + Fixes to RPM spec file.
  + Distribute RPM spec file.
  + Complement some getters with corresponding gobject properties.
  + Few other random minor fixes.
- Add libtool BuildRequires
- Split typelib file in typelib-1_0-Libosinfo-1_0
- Add typelib-1_0-Libosinfo-1_0 Requires to -devel package.
* Wed Nov 23 2011 dimstar@opensuse.org
- Initial package, version 0.0.2
